import { PackageInfo } from '../types';
import * as vscode from 'vscode';
import { OptionsBuilderBase } from './optionsBuilderBase';
/**
 * Class to build options more easily than inheriting from OptionsBuilderBase.
 */
export declare class EasyOptionsBuilder extends OptionsBuilderBase {
    private _flags;
    private _parameters;
    private _listParameters;
    private _additionalOptions;
    /**
     * Flag options for the package.
     */
    protected get flags(): string[];
    /**
     * Parameter options for the package.
     */
    protected get parameters(): string[];
    /**
     * List parameter options for the package.
     */
    protected get listParameters(): string[];
    /**
     * Additional options for the package.
     */
    protected get additionalOptions(): string[];
    /**
     * @param packageInfo Information about the package.
     * @param flags Flag options for the package.
     * @param parameters Parameter options for the package.
     * @param listParameters List parameter options for the package.
     * @param additionalOptions Additional options for the package.
     */
    constructor(packageInfo: PackageInfo, flags: string[], parameters: string[], listParameters: string[], additionalOptions?: string[]);
    build(uris: vscode.Uri[]): Promise<string[]>;
}
