import { PackageInfo } from '../types';
import { IOptionsBuilder } from './types';
import * as vscode from 'vscode';
import { OptionsBuilderHelper } from './optionsBuilderHelper';
/**
 * Base class to build options for a Python package. Inherit from this class to build options for a specific package.
 */
export declare class OptionsBuilderBase implements IOptionsBuilder {
    private _packageInfo;
    /**
     * Information about the package.
     */
    get packageInfo(): PackageInfo;
    private _optionsBuilderHelper;
    /**
     * Helper to build options.
     */
    protected get optionsBuilderHelper(): OptionsBuilderHelper;
    /**
     * @param packageInfo Information about the package.
     */
    constructor(packageInfo: PackageInfo);
    /**
     * Base implementation of build. Override this method to build options for a specific package.
     * @param uris File paths and folder paths to run package for.
     * @returns Options for the package.
     */
    build(uris: vscode.Uri[]): Promise<string[]>;
}
