import * as vscode from 'vscode';
/**
 * Helper class to create command line arguments from vscode Workspace Configuration.
 */
export declare class OptionsBuilderHelper {
    private _config;
    get config(): vscode.WorkspaceConfiguration;
    private _flagPrefix;
    /**
     * @param config Workspace Configuration.
     * @param flagPrefix Prefix of the command line arguments. e.g. '--', sometimes '-'.
     */
    constructor(config: vscode.WorkspaceConfiguration, flagPrefix?: string);
    /**
     * Build command line arguments from a list of flags.
     * @param flags Array of flag names. Each flag name must not contain the flag prefix, e.g. '--'. e.g. 'verbose' is a valid flag name, '--verbose' is not.
     * @returns Array of command line arguments.
     */
    buildFlags(flags: string[]): string[];
    /**
     * Build command line arguments from a list of parameters.
     * @param parameters Array of parameter names. Each parameter name must not contain the flag prefix, e.g. '--'. e.g. 'verbose' is a valid parameter name, '--verbose' is not.
     * @returns Array of command line arguments.
     */
    buildParameters(parameters: string[]): string[];
    /**
     * Build command line arguments from a list of list parameters.
     * @param listParameters Array of parameter names. Each parameter name must not contain the flag prefix, e.g. '--'. e.g. 'verbose' is a valid parameter name, '--verbose' is not.
     * @returns Array of command line arguments.
     */
    buildListParameters(listParameters: string[]): string[];
    /**
     * Convert a parameter name to a command line argument. (e.g. 'verbose' to '--verbose')
     * @param name Name of the parameter. Must not contain the flag prefix, e.g. '--'. e.g. 'verbose' is a valid parameter name, '--verbose' is not.
     * @returns Expression of the parameter, e.g. '--verbose'.
     */
    buildParameterExpression(name: string): string;
}
